pub struct LicensePlateRecognizer {
pub config: PlateConfig,
pub model_name: String,
/* private fields */
}Expand description
Inference class for license-plate OCR using tract-onnx.
Fields
config: PlateConfigPlate configuration (image size, alphabet, etc.).
model_name: StringHuman-readable model name.
Implementations
Sourceimpl LicensePlateRecognizer
impl LicensePlateRecognizer
Sourcepub fn from_files(
onnx_model_path: impl AsRef<Path>,
plate_config_path: impl AsRef<Path>,
) -> Result<Self>
pub fn from_files( onnx_model_path: impl AsRef<Path>, plate_config_path: impl AsRef<Path>, ) -> Result<Self>
Build a recognizer from an existing ONNX model file and config file.
Sourcepub fn from_hub(model: OcrModel, force_download: bool) -> Result<Self>
pub fn from_hub(model: OcrModel, force_download: bool) -> Result<Self>
Download (if necessary) and load a model from the hub.
Sourcepub fn from_hub_to_dir(
model: OcrModel,
save_dir: &Path,
force_download: bool,
) -> Result<Self>
pub fn from_hub_to_dir( model: OcrModel, save_dir: &Path, force_download: bool, ) -> Result<Self>
Download (if necessary) and load a model from the hub, saving to a specific directory.
Sourcepub fn run(
&self,
inputs: &[PlateInput<'_>],
return_confidence: bool,
remove_pad_char: bool,
) -> Result<Vec<PlatePrediction>>
pub fn run( &self, inputs: &[PlateInput<'_>], return_confidence: bool, remove_pad_char: bool, ) -> Result<Vec<PlatePrediction>>
Run plate recognition on one or more plate images.
inputs is a slice of PlateInput (paths or pre-loaded images).
Returns one PlatePrediction per input.
Sourcepub fn run_one(
&self,
input: PlateInput<'_>,
return_confidence: bool,
remove_pad_char: bool,
) -> Result<PlatePrediction>
pub fn run_one( &self, input: PlateInput<'_>, return_confidence: bool, remove_pad_char: bool, ) -> Result<PlatePrediction>
Convenience wrapper for a single image.
Sourcepub fn benchmark(
&self,
n_iter: usize,
batch_size: usize,
warmup: usize,
include_processing: bool,
) -> Result<()>
pub fn benchmark( &self, n_iter: usize, batch_size: usize, warmup: usize, include_processing: bool, ) -> Result<()>
Run a simple throughput benchmark and print the results to stdout.
n_iter– number of timed iterationsbatch_size– images per “batch” (each is run individually due to tract’s fixed shape)warmup– number of warm-up iterations (not counted)include_processing– iftrue, preprocessing / postprocessing are included in the timing.